Display BLS Dataset Overview
bls_overview.RdFetches and displays the overview text file for a BLS dataset. This provides a convenient reference within the R environment without needing to manually find and review the text file on the BLS website.
Usage
bls_overview(
series_id,
display_method = "viewer",
base_url = "https://download.bls.gov/pub/time.series"
)Value
Invisibly returns the text content. Function is called to use the viewer, console, or as a popup, depending on the 'display_method' argument.
Examples
# \donttest{
if(interactive()){
# Display Average Price Data overview
bls_overview("ap")
# Display consumer price index overview
bls_overview("cu")
# Display in console instead of viewer
bls_overview("ap", display_method = "console")
}
# }