View source: R/download_helpers.R
| get_bls_excel_headers | R Documentation |
Returns a named character vector of HTTP headers required for BLS API requests. These headers mimic a standard browser to ensure compatibility with BLS servers. This function returns a more limited set of headers used to download an Ecel file.
get_bls_excel_headers(refer = "https://www.bls.gov/lau/stalt-archived.htm")
refer |
The URL to use in the Referer header (default: "https://www.bls.gov/lau/stalt-archived.htm") |
A named character vector of HTTP headers
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.