get_bls_summary: Get summary information from BLS data object

View source: R/download_helpers.R

get_bls_summaryR Documentation

Get summary information from BLS data object

Description

This is a helper function to extract the summary element of a 'bls_data_collection' object. This containes the number of files downloaded, the number of files with potential warnings, and the total number of warnings.

Usage

get_bls_summary(bls_obj)

Arguments

bls_obj

A bls_data_collection object

Value

List of summary information


BLSloadR documentation built on April 23, 2026, 9:07 a.m.