check_bls_cache_env: Check if Global Caching is Enabled via Environment Variable

View source: R/download_helpers.R

check_bls_cache_envR Documentation

Check if Global Caching is Enabled via Environment Variable

Description

Check if Global Caching is Enabled via Environment Variable

Usage

check_bls_cache_env()

Value

Logical value indicating if the environment variable USE_BLS_CACHE is one of TRUE, YES, or 1


BLSloadR documentation built on April 23, 2026, 9:07 a.m.