| fread_bls | R Documentation |
This function downloads a tab-delimited BLS flat file, incorporating diagnostic information about the file and returning an object with the bls_data class that can be used in the BLSloadR package.
fread_bls(url, verbose = FALSE, cache = check_bls_cache_env())
url |
Character string. URL to the BLS flat file |
verbose |
Logical. If TRUE, prints additional messages during file read and processing. |
cache |
Logical. If TRUE, uses local persistent caching. |
A named list with the data and diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.