View source: R/download_helpers.R
| get_bls_summary | R Documentation |
This is a helper function to extract the summary element of a 'bls_data_collection' object. This containes the number of files downloaded, the number of files with potential warnings, and the total number of warnings.
get_bls_summary(bls_obj)
bls_obj |
A bls_data_collection object |
List of summary information
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.