| list_ces_industries | R Documentation |
Lists all available industry categories that can be used with the 'industry_filter' parameter in 'get_ces()' function. These filters allow you to download specific industry data instead of the complete dataset.
list_ces_industries(show_descriptions = FALSE)
show_descriptions |
Logical. If TRUE, returns a data frame with filter names and descriptions. If FALSE, returns just the filter names. |
A character vector of industry filter names, or a data frame with names and descriptions if show_descriptions = TRUE
# See all available industry filters
list_ces_industries()
# See filters with descriptions
list_ces_industries(show_descriptions = TRUE)
# Use with get_ces
# manufacturing_data <- get_ces(industry_filter = "manufacturing") # All states
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.